@@ -43,7 +43,6 @@ namespace DbUtils
 
 static Glib::RefPtr<Gnome::Gda::Connection> get_connection()
 {
-
   sharedptr<SharedConnection> sharedconnection;
   try
   {
@@ -553,9 +552,10 @@ bool add_standard_groups(Document* document)
     type_vec_strings::const_iterator iterFind = std::find(vecGroups.begin(), vecGroups.end(), devgroup);
     if(iterFind == vecGroups.end())
     {
+      //TODO: Escape and quote the user and group names here?
       //The "SUPERUSER" here has no effect because SUPERUSER is not "inherited" to member users.
       //But let's keep it to make the purpose of this group obvious.
-      bool test = query_execute_string("CREATE GROUP \"" GLOM_STANDARD_GROUP_NAME_DEVELOPER "\" WITH SUPERUSER");
+      bool test = query_execute_string("CREATE GROUP " + DbUtils::escape_sql_id(GLOM_STANDARD_GROUP_NAME_DEVELOPER) + " WITH SUPERUSER");
       if(!test)
       {
         std::cerr << G_STRFUNC << ": CREATE GROUP failed when adding the developer group." << std::endl;
@@ -565,7 +565,7 @@ bool add_standard_groups(Document* document)
       //Make sure the current user is in the developer group.
       //(If he is capable of creating these groups then he is obviously a developer, and has developer rights on the postgres server.)
       const Glib::ustring current_user = ConnectionPool::get_instance()->get_user();
-      const Glib::ustring strQuery = "ALTER GROUP \"" GLOM_STANDARD_GROUP_NAME_DEVELOPER "\" ADD USER \"" + current_user + "\"";
+      const Glib::ustring strQuery = "ALTER GROUP " + DbUtils::escape_sql_id(GLOM_STANDARD_GROUP_NAME_DEVELOPER) + " ADD USER " + DbUtils::escape_sql_id(current_user);
       test = query_execute_string(strQuery);
       if(!test)
       {
@@ -617,6 +617,10 @@ bool add_groups_from_document(Document* document)
     std::cerr << G_STRFUNC << ": add_standard_groups(): No connection yet." << std::endl;
   }
 
+  // If the connection doesn't support users we can skip this step
+  if(!(gda_connection->supports_feature(Gnome::Gda::CONNECTION_FEATURE_USERS)))
+    return true;
+
   //Get the list of groups from the database server:
   const type_vec_strings database_groups = Privs::get_database_groups();
 
@@ -634,7 +638,7 @@ bool add_groups_from_document(Document* document)
     type_vec_strings::const_iterator iterFind = std::find(database_groups.begin(), database_groups.end(), name);
     if(!name.empty() && iterFind == database_groups.end())
     {
-      Glib::ustring query = "CREATE GROUP \"" + name  + "\"";
+      Glib::ustring query = "CREATE GROUP " + escape_sql_id(name);
 
       //The "SUPERUSER" here has no effect because SUPERUSER is not "inherited" to member users.
       //But let's keep it to make the purpose of this group obvious.
@@ -661,6 +665,10 @@ bool set_table_privileges_groups_from_document(Document* document)
     std::cerr << G_STRFUNC << ": add_standard_groups(): No connection yet." << std::endl;
   }
 
+  // If the connection doesn't support users we can skip this step
+  if(!(gda_connection->supports_feature(Gnome::Gda::CONNECTION_FEATURE_USERS)))
+    return true;
+
   //Get the list of groups from the database server:
   const type_vec_strings database_groups = Privs::get_database_groups();
 
@@ -1079,20 +1087,6 @@ bool create_table_with_default_fields(Document* document, const Glib::ustring& t
 
   created = create_table(table_info, fields);
 
-    //Create a table with 1 "ID" field:
-   //MSYQL:
-    //query_execute( "CREATE TABLE \"" + table_name + "\" (" + primary_key_name + " INT NOT NULL AUTO_INCREMENT PRIMARY KEY)" );
-    //query_execute( "INSERT INTO \"" + table_name + "\" VALUES (0)" );
-
-    //PostgresSQL:
-    //query_execute( "CREATE TABLE \"" + table_name + "\" (\"" + primary_key_name + "\" serial NOT NULL  PRIMARY KEY)" );
-
-    //query_execute( "CREATE TABLE \"" + table_name + "\" (" +
-    //  field_primary_key->get_name() + " numeric NOT NULL  PRIMARY KEY," +
-    //  extra_field_description + "varchar, " +
-    //  extra_field_comments + "varchar" +
-    //  ")" );
-
   if(created)
   {
     //Save the changes in the document:
@@ -1137,7 +1131,7 @@ bool create_table(const sharedptr<const TableInfo>& table_info, const Document::
     info->set_g_type( Field::get_gda_type_for_glom_type(field->get_glom_type()) );
     field->set_field_info(info); //TODO_Performance
 
-    Glib::ustring sql_field_description = "\"" + field->get_name() + "\" " + field->get_sql_type();
+    Glib::ustring sql_field_description = escape_sql_id(field->get_name()) + " " + field->get_sql_type();
 
     if(field->get_primary_key())
       sql_field_description += " NOT NULL  PRIMARY KEY";
@@ -1159,7 +1153,7 @@ bool create_table(const sharedptr<const TableInfo>& table_info, const Document::
   {
     //TODO: Escape the table name?
     //TODO: Use GDA_SERVER_OPERATION_CREATE_TABLE instead?
-    table_creation_succeeded = query_execute_string( "CREATE TABLE \"" + table_info->get_name() + "\" (" + sql_fields + ");" );
+    table_creation_succeeded = query_execute_string( "CREATE TABLE " + escape_sql_id(table_info->get_name()) + " (" + sql_fields + ");" );
     if(!table_creation_succeeded)
       std::cerr << G_STRFUNC << ": CREATE TABLE failed." << std::endl;
   }
@@ -1850,6 +1844,39 @@ int count_rows_returned_by(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& sql
   return result;
 }
 
+bool rename_table(const Glib::ustring& table_name, const Glib::ustring& new_table_name)
+{
+  //TODO: Escape the table names:
+  return query_execute_string( "ALTER TABLE " + escape_sql_id(table_name) + " RENAME TO " + escape_sql_id(new_table_name));
+}
+
+bool drop_table(const Glib::ustring& table_name)
+{
+  //TODO: Escape the table names:
+  return DbUtils::query_execute_string( "DROP TABLE " + escape_sql_id(table_name));
+}
+
+Glib::ustring escape_sql_id(const Glib::ustring& id)
+{
+  if(id.empty())
+  {
+    std::cerr << G_STRFUNC << ": id is empty." << std::endl;
+    return id;
+  }
+
+  Glib::RefPtr<Gnome::Gda::Connection> gda_connection = get_connection();
+  if(!gda_connection)
+  {
+    std::cerr << G_STRFUNC << ": No gda_connection." << std::endl;
+    return id;
+  }
+
+  //Always put it in quotes even if 
+
+  return gda_connection->quote_sql_identifier(id);
+}
+
+
 } //namespace DbUtils
 
 } //namespace Glom
