@@ -139,6 +139,18 @@ Glib::ustring get_unused_database_name(const Glib::ustring& base_name);
  */
 int count_rows_returned_by(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& sql_query);
 
+/** Rename a table in the database.
+ */
+bool rename_table(const Glib::ustring& table_name, const Glib::ustring& new_table_name);
+
+/* Remove a table from the database.
+ */
+bool drop_table(const Glib::ustring& table_name);
+
+/** Escape, and quote, SQL identifiers such as table names.
+ */
+Glib::ustring escape_sql_id(const Glib::ustring& id);
+
 } //namespace DbUtils
 
 } //namespace Glom
