@@ -379,7 +379,7 @@ void Utils::build_sql_select_add_fields_to_get(const Glib::RefPtr<Gnome::Gda::Sq
     {
       const Gnome::Gda::SqlBuilder::Id id_function = builder->add_function(
         fieldsummary->get_summary_type_sql(),
-        builder->add_id(layout_item->get_sql_name(table_name)) ); //TODO: Just use add_field_id()?
+        builder->add_field_id(layout_item->get_name(), table_name));
       builder->add_field_value_id(id_function);
     }
     else
