@@ -25,6 +25,7 @@
 #include <glom/base_db.h>
 #include <glom/utility_widgets/adddel/adddel_withbuttons.h>
 #include <gtkmm/builder.h>
+#include <gtkmm/checkbutton.h>
 
 namespace Glom
 {
@@ -38,6 +39,9 @@ class Box_Tables
   public Base_DB
 {
 public:
+  static const char* glade_id;
+  static const bool glade_developer;
+
   Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Box_Tables();
 
@@ -60,7 +64,6 @@ private:
 
   virtual void on_userlevel_changed(AppState::userlevels userlevel);
       
-  Gtk::Label* m_pLabelFrameTitle;
   Gtk::CheckButton* m_pCheckButtonShowHidden;
   guint m_colTableName;
   guint m_colHidden;
